Trait PyAnySerde
Source pub trait PyAnySerde: DynClone {
// Required methods
fn append<'py>(
&mut self,
buf: &mut [u8],
offset: usize,
obj: &Bound<'py, PyAny>,
) -> PyResult<usize>;
fn append_vec<'py>(
&mut self,
v: &mut Vec<u8>,
start_addr: Option<usize>,
obj: &Bound<'py, PyAny>,
) -> PyResult<()>;
fn retrieve<'py>(
&mut self,
py: Python<'py>,
buf: &[u8],
offset: usize,
) -> PyResult<(Bound<'py, PyAny>, usize)>;
// Provided methods
fn append_option<'py>(
&mut self,
buf: &mut [u8],
offset: usize,
obj_option: &Option<&Bound<'py, PyAny>>,
) -> PyResult<usize> { ... }
fn append_option_vec<'py>(
&mut self,
v: &mut Vec<u8>,
start_addr: Option<usize>,
obj_option: &Option<&Bound<'py, PyAny>>,
) -> PyResult<()> { ... }
fn retrieve_option<'py>(
&mut self,
py: Python<'py>,
buf: &[u8],
offset: usize,
) -> PyResult<(Option<Bound<'py, PyAny>>, usize)> { ... }
}
Extracts
Self from the bound smart pointer
obj.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.